
{% extends "!layout.html" %}
<!--
  General templating guide: https://www.sphinx-doc.org/en/master/templating.html#blocks
  RTD template blocks: https://github.com/readthedocs/sphinx_rtd_theme/blob/master/sphinx_rtd_theme/layout.html
  Dark mode toggle: https://dev.to/ananyaneogi/create-a-dark-light-mode-switch-with-css-variables-34l8
  Edit extrahead: https://stackoverflow.com/questions/23211695/modifying-content-width-of-the-sphinx-theme-read-the-docs
  Edit footer: https://stackoverflow.com/a/48281750/4970632
  Using css_files: https://stackoverflow.com/a/32079202/4970632
  * Critical to put dark mode toggle script at footer after HTML
    classes are already defined.
  * Critical to use pathto() instead of "_static/custom.css" because auto
    generated docs are in "api" subfolder so link becomes invalid!
  * Use extrahead because it is recommended in templating instructions,
    css_files method does *not require* pathto() but do not understand why
-->
{% block extrahead %}
  <link rel="stylesheet" href="{{ pathto("_static/pygments/default.css", True) }}" type="text/css" id="pygments-style">
  <link rel="stylesheet" href="{{ pathto("_static/custom.css", True) }}" type="text/css">
  {{ super() }}
{% endblock %}
{% block document %}
  <script type="text/javascript" src={{ pathto("_static/custom.js", True) }}></script>
  {{ super() }}
{% endblock %}

