
{% extends "!breadcrumbs.html" %}
<!--
  Put dark mode toggle inside breadcrumbs header
  See layout.html for details
  Name class btn-neutral so it inherits properties of other RTD buttons
-->
{% block breadcrumbs %}
  <!--
  <div class="admonition note">
    <p><a href="https://github.com/lukelbd">ProPlot author here</a>: Due to my day job as a graduate student, certain <a href="https://github.com/lukelbd/proplot/pulls?q=is%3Aopen+is%3Apr">feature additions</a> may be delayed to the summer of 2020. In the meantime, if you are interested in contributing to ProPlot, please see the <a href="https://proplot.readthedocs.io/en/latest/contributions.html">contribution guide</a>. Any amount of help is welcome!
    </p>
  </div>
  -->
  <li id="lightdark-li">
    <label for="lightdark-checkbox" id="lightdark-label">
      <input type="checkbox" id="lightdark-checkbox"/>
      <div class="btn-neutral"></div>
    </label>
  </li>
  {{ super() }}
{% endblock %}
  
