.highlight .hll { background-color: #ffffcc }
.highlight  { background: #ffffff; color: #111111 }
.highlight .c { color: #008800; font-style: italic } /* Comment */
.highlight .err { color: #a61717; background-color: #e3d2d2 } /* Error */
.highlight .k { color: #353580; font-weight: bold } /* Keyword */
.highlight .ch { color: #008800; font-style: italic } /* Comment.Hashbang */
.highlight .cm { color: #008800; font-style: italic } /* Comment.Multiline */
.highlight .cp { color: #008800; font-style: italic } /* Comment.Preproc */
.highlight .cpf { color: #008800; font-style: italic } /* Comment.PreprocFile */
.highlight .c1 { color: #008800; font-style: italic } /* Comment.Single */
.highlight .cs { color: #008800; font-style: italic } /* Comment.Special */
.highlight .kc { color: #353580; font-weight: bold } /* Keyword.Constant */
.highlight .kd { color: #353580; font-weight: bold } /* Keyword.Declaration */
.highlight .kn { color: #353580; font-weight: bold } /* Keyword.Namespace */
.highlight .kp { color: #353580; font-weight: bold } /* Keyword.Pseudo */
.highlight .kr { color: #353580; font-weight: bold } /* Keyword.Reserved */
.highlight .kt { color: #353580; font-weight: bold } /* Keyword.Type */
.highlight .m { color: #2c2cff } /* Literal.Number */
.highlight .s { color: #7a2424 } /* Literal.String */
.highlight .nf { color: #2c2cff } /* Name.Function */
.highlight .nx { color: #be646c } /* Name.Other */
.highlight .nv { color: #35baba; font-weight: bold } /* Name.Variable */
.highlight .w { color: #bbbbbb } /* Text.Whitespace */
.highlight .mb { color: #2c2cff } /* Literal.Number.Bin */
.highlight .mf { color: #2c2cff } /* Literal.Number.Float */
.highlight .mh { color: #2c2cff } /* Literal.Number.Hex */
.highlight .mi { color: #2c2cff } /* Literal.Number.Integer */
.highlight .mo { color: #2c2cff } /* Literal.Number.Oct */
.highlight .sa { color: #7a2424 } /* Literal.String.Affix */
.highlight .sb { color: #7a2424 } /* Literal.String.Backtick */
.highlight .sc { color: #7a2424 } /* Literal.String.Char */
.highlight .dl { color: #7a2424 } /* Literal.String.Delimiter */
.highlight .sd { color: #7a2424 } /* Literal.String.Doc */
.highlight .s2 { color: #7a2424 } /* Literal.String.Double */
.highlight .se { color: #7a2424 } /* Literal.String.Escape */
.highlight .sh { color: #7a2424 } /* Literal.String.Heredoc */
.highlight .si { color: #7a2424 } /* Literal.String.Interpol */
.highlight .sx { color: #7a2424 } /* Literal.String.Other */
.highlight .sr { color: #7a2424 } /* Literal.String.Regex */
.highlight .s1 { color: #7a2424 } /* Literal.String.Single */
.highlight .ss { color: #7a2424 } /* Literal.String.Symbol */
.highlight .fm { color: #2c2cff } /* Name.Function.Magic */
.highlight .vc { color: #35baba; font-weight: bold } /* Name.Variable.Class */
.highlight .vg { color: #b5565e; font-weight: bold } /* Name.Variable.Global */
.highlight .vi { color: #35baba; font-weight: bold } /* Name.Variable.Instance */
.highlight .vm { color: #35baba; font-weight: bold } /* Name.Variable.Magic */
.highlight .il { color: #2c2cff } /* Literal.Number.Integer.Long */